"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const plugin_utilities_1 = require("@rxap/plugin-utilities");
const utilities_1 = require("@rxap/utilities");
const path_1 = require("path");
const typedoc_1 = require("typedoc");
const runExecutor = (options, context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    var _a;
    console.log('Executor ran for Build', options);
    const projectSourceRoot = (0, plugin_utilities_1.GetProjectSourceRoot)(context);
    const projectRoot = (0, plugin_utilities_1.GetProjectRoot)(context);
    const { tsConfig: tsconfig = (0, path_1.join)(projectRoot, 'tsconfig.lib.json') } = (0, plugin_utilities_1.GetProjectTargetOptions)(context, context.projectName, 'build');
    const entryPoints = (_a = options.entryPoints) !== null && _a !== void 0 ? _a : [];
    if (entryPoints.length === 0) {
        entryPoints.push((0, path_1.join)(projectSourceRoot, 'index.ts'));
    }
    const outputPath = (0, utilities_1.coerceArray)(options.outputPath);
    if (outputPath.length === 0) {
        const outputDir = projectRoot === '/' ? context.projectName : projectRoot;
        outputPath.push((0, path_1.join)('dist', 'docs', outputDir));
    }
    console.log('entryPoints:', entryPoints);
    console.debug('Creating Application');
    const app = yield typedoc_1.Application.bootstrapWithPlugins({
        entryPoints: entryPoints, //.map(entryPoint => relative(projectRoot, entryPoint)),
        skipErrorChecking: true,
        tsconfig,
    });
    console.debug('Converting');
    const project = yield app.convert();
    if (!project) {
        return { success: false };
    }
    for (const path of outputPath) {
        console.log('Generating docs at:', path);
        // Rendered docs
        yield app.generateDocs(project, path);
        // Alternatively, generate JSON output
        yield app.generateJson(project, (0, path_1.join)(path, `documentation.json`));
    }
    return {
        success: true,
    };
});
exports.default = runExecutor;
//# sourceMappingURL=executor.js.map